<?php
// vim:filetype=php expandtab tabstop=2 softtabstop=2 shiftwidth=2 autoindent smartindent
// $Id: tribune.admin.inc,v 1.1.2.4 2009/04/10 17:40:59 seeschloss Exp $

function tribune_admin() {
  drupal_set_title(t("Tribune settings"));
  $breadcrumb = drupal_get_breadcrumb();
  $breadcrumb[] = l(t("Tribune settings"), "admin/settings/tribune");
  drupal_set_breadcrumb($breadcrumb);

  $form['tribune_max_message_size'] = array(
    '#type'           => 'textfield',
    '#title'          => t('Maximum length of a comment'),
    '#default_value'  => variable_get('tribune_max_message_size', 512),
    '#size'           => 4,
    '#maxlength'      => 4,
    '#description'    => t('The maximum length of a comment.'),
  );

  $form['tribune_history_size'] = array(
    '#type'           => 'textfield',
    '#title'          => t('Number of comments displayed'),
    '#default_value'  => variable_get('tribune_history_size', 25),
    '#size'           => 3,
    '#maxlength'      => 3,
    '#description'    => t('The number of comments to display.'),
  );

  $form['tribune_history_block_size'] = array(
    '#type'           => 'textfield',
    '#title'          => t('Number of comments displayed in the block'),
    '#default_value'  => variable_get('tribune_history_block_size', 10),
    '#size'           => 3,
    '#maxlength'      => 3,
    '#description'    => t('The number of comments to display in the block.'),
  );

  $form['tribune_xml_size'] = array(
    '#type'           => 'textfield',
    '#title'          => t('Number of comments displayed in the XML backend'),
    '#default_value'  => variable_get('tribune_xml_size', 100),
    '#size'           => 3,
    '#maxlength'      => 3,
    '#description'    => t('The number of comments to display in the XML backend.'),
  );

  $form['tribune_rss_size'] = array(
    '#type'           => 'textfield',
    '#title'          => t('Number of comments displayed in the RSS feed'),
    '#default_value'  => variable_get('tribune_rss_size', 50),
    '#size'           => 3,
    '#maxlength'      => 3,
    '#description'    => t('The number of comments to display in the RSS feed.'),
  );

  $form['tribune_reload_delay'] = array(
    '#type'           => 'textfield',
    '#title'          => t('Reload delay'),
    '#default_value'  => variable_get('tribune_reload_delay', 30),
    '#size'           => 3,
    '#maxlength'      => 3,
    '#description'    => t('The delay between automatic reloading of the tribune, in seconds (0 to disable Ajax reloading).'),
  );

  $form['tribune_idle_delay'] = array(
    '#type'           => 'textfield',
    '#title'          => t('Idle delay'),
    '#default_value'  => variable_get('tribune_idle_delay', 0),
    '#size'           => 3,
    '#maxlength'      => 3,
    '#description'    => t('The delay before the tribune stop automatically reloading when an user is inactive, in seconds (0 to disable idle mode).'),
  );

  $form['tribune_name'] = array(
    '#type'           => 'textfield',
    '#title'          => t('Tribune name'),
    '#default_value'  => variable_get('tribune_name', variable_get('site_name', '')),
    '#description'    => t('The name of your tribune, needed for people who use Coincoins.'),
  );

  $form['tribune_message'] = array(
    '#type'           => 'textarea',
    '#title'          => t('Tribune message'),
    '#default_value'  => variable_get('tribune_message', ''),
    '#description'    => t('Warning or information to display at the top of the tribune. You can use any HTML code you want, but you have to insert linebreaks yourself.'),
  );

  $form['tribune_flood_protection_delay'] = array(
    '#type'           => 'textfield',
    '#title'          => t('Flood protection'),
    '#default_value'  => variable_get('tribune_flood_protection_delay', 3),
    '#size'           => 3,
    '#maxlength'      => 3,
    '#description'    => t('Minimum time before someone can post again, in seconds.'),
  );

  $form['tribune_order'] = array(
    '#type'           => 'radios',
    '#title'          => t('Message order'),
    '#default_value'  => variable_get('tribune_order', 'top_to_bottom'),
    '#options'        => array('top_to_bottom' => t("Last messages at the bottom"), 'bottom_to_top' => t("Last messages at the top")),
    '#description'    => t('How the messages are displayed. Displaying the messages top-to-bottom makes it easier to follow real discussions, but displaying the latest one at the top is sometimes less confusing.'),
  );

  $form['tribune_pager'] = array(
    '#type'           => 'checkbox',
    '#title'          => t('Show pager'),
    '#default_value'  => variable_get('tribune_pager', FALSE),
    '#description'    => t('Show a pager on the main page.'),
  );

  $form['tribune_discreet_notification'] = array(
    '#type'           => 'checkbox',
    '#title'          => t('Discreet notification of new posts'),
    '#default_value'  => variable_get('tribune_discreet_notification', FALSE),
    '#description'    => t('Show a discreet notification for new posts. In any case when a new post arrives, a "*" is prepended to the tab title, or a "#" when the new post is an answer. If left unchecked, the favicon will also be changed for more visibility.'),
  );

  $form['tribune_antispam'] = array(
    '#type'           => 'checkbox',
    '#title'          => t('Insert a hidden antispam field'),
    '#default_value'  => variable_get('tribune_antispam', TRUE),
    '#description'    => t('An antispam field (called "email" and hidden through CSS) will be added to the post form. If it is not empty, the post will be ignored, this usually works very well against spammers.'),
  );

  return system_settings_form($form);
}

function tribune_admin_validate($form_id, $form_values) {
  if (!is_numeric($form_values['values']['tribune_max_message_size'])) {
    form_set_error("tribune_max_message_size", t("The maximum comment length must be an integer"));
  }

  if (!is_numeric($form_values['values']['tribune_history_size'])) {
    form_set_error("tribune_history_size", t("The number of comments displayed must be an integer"));
  }

  if (!is_numeric($form_values['values']['tribune_history_block_size'])) {
    form_set_error("tribune_history_block_size", t("The number of comments displayed in the block must be an integer"));
  }

  if (!is_numeric($form_values['values']['tribune_xml_size'])) {
    form_set_error("tribune_xml_size", t("The number of comments in the XML backend must be an integer"));
  }

  if (!is_numeric($form_values['values']['tribune_reload_delay'])) {
    form_set_error("tribune_reload_delay", t("The reload delay must be a time in seconds"));
  }

  if (strlen($form_values['values']['tribune_message']) > 2048) {
    $form_values['values']['tribune_message'] =
      substr($form_values['values']['tribune_message'], 0, 2048);
  }

  if (!is_numeric($form_values['values']['tribune_flood_protection_delay'])) {
    form_set_error("tribune_flood_protection_delay", t("The flood protection delay must be a time in seconds"));
  }
}

