<?php
// vim:filetype=php expandtab tabstop=2 softtabstop=2 shiftwidth=2 autoindent smartindent
// $Id: tribune.backend.inc,v 1.1.2.4 2010/04/20 08:00:57 seeschloss Exp $


/**
  * Print the XML backend
  */
function tribune_xml() {
  $since = isset($_SERVER['HTTP_IF_MODIFIED_SINCE']) ? stripslashes($_SERVER['HTTP_IF_MODIFIED_SINCE']) : FALSE;

  header("Content-Type: text/xml");
  if ($since) {
    $posts = get_new_posts(strtotime($since));
  } else {
    $posts = get_last_posts(variable_get('tribune_xml_size', 100));
  }
  $last_modified = end($posts);
  header("Last-Modified: ".gmdate('r', $last_modified['last_modified']));
  print theme("tribune_xml", $posts);
  exit();
}

/**
  * Returns the $nb last posts, in XML format
  * @param nb Number of posts to return (tribune_history_size by default)
  * @return String containing the posts in an HTML unordered list
  */
function theme_tribune_xml($posts) {
  $contents  = "<?xml version=\"1.0\" encoding=\"UTF-8\""."?".">\n";
  $contents .= "<!DOCTYPE board PUBLIC \"C01N C01N !\" \"http://phplop.org/dtd/tribune-1.0.dtd\">\n";

  $timezone = variable_get('date_default_timezone', 0);
  $tz = "UTC". ($timezone < 0 ? "-" : "+") . round($timezone/3600);
  $contents .= "<board site=\"". url('tribune', array('absolute' => TRUE)) ."\" timezone=\"". $tz ."\">\n";

  $posts = array_reverse($posts);

  $filters = _tribune_get_filters(TRUE);
  if (isset($filters['url'])) {
    $url_function = $filters['url'];
    $dummy = "";
  } else {
    $url_function = false;
  }

  foreach ($posts as $id => $post) {
    if ($post['moderated'] == 0) {
      $post['parsed'] = tribune_slip($post['message']);

      if ($url_function) {
        $url_function($post, $dummy);
      } else {
        $post['parsed'] = preg_replace('#((https?|ftp|gopher|file|mms|rtsp|rtmp)://.*?)((,|\.|\)|\])?(<| | |"|$))#', '<a href="\1">[url]</a>\3', $post['parsed']);
      }

      $contents .= theme("tribune_post_xml", $post);
    }
  }

  $contents .= "</board>\n";

  return $contents;
}

/**
  * Returns a single post, in XML format
  * @param post Array with the following keys : id, clock, login, info, message
  */
function theme_tribune_post_xml($post) {
  $contents  = "    <post time=\"". $post['clock']  ."\" id=\"". $post['id'] ."\">\n";
  $contents .= "        <info><![CDATA["   . $post['info']   ."]]></info>\n";
  $contents .= "        <message><![CDATA[". $post['parsed'] ."]]></message>\n";
  $contents .= "        <login><![CDATA["  . $post['login']  ."]]></login>\n";
  $contents .= "    </post>\n";

  return $contents;
}
