<?php
// vim:filetype=php expandtab tabstop=2 softtabstop=2 shiftwidth=2 autoindent smartindent
// $Id: tribune.rss.inc,v 1.2.2.4 2008/12/17 13:48:31 seeschloss Exp $


/**
  * Print the RSS feed
  */
function tribune_rss() {
  header("Content-Type: application/rss+xml");
  $posts = get_last_posts(variable_get('tribune_rss_size', 50));
  print theme("tribune_rss", $posts);
  exit();
}

/**
  * Returns the $nb last posts, in XML format
  * @param nb Number of posts to return (tribune_history_size by default)
  * @return String containing the posts in an HTML unordered list
  */
function theme_tribune_rss($posts) {

  $contents  = "<?xml version=\"1.0\"?>\n";
  $contents .= "<rss version=\"2.0\">\n";
  $contents .= "\t<channel>\n";
  $contents .= "\t\t<title>".variable_get("site_name", "")."</title>\n";
  $contents .= "\t\t<link>".url("tribune", array('absolute' => TRUE))."</link>\n";
  $contents .= "\t\t<description>".variable_get("site_slogan", "")."</description>\n";

  $posts = array_reverse($posts, TRUE);

  foreach ($posts as $id => $post) {
    if ($post['moderated'] == 0) {
      $contents .= theme("tribune_post_rss", $post);
    }
  }

  $contents .= "\t</channel>\n";
  $contents .= "</rss>\n";

  return $contents;
}

/**
  * Returns a single post, in RSS format
  * @param post Array with the following keys : id, clock, login, info, message
  */
function theme_tribune_post_rss($post) {
  $contents  = "\t\t<item>\n";
  $contents .= "\t\t\t<description>". tribune_rss_slip($post['message']) ."</description>\n";
  $contents .= "\t\t\t<pubDate>". date('r', tribune_date_to_timestamp($post['post_time'])) ."</pubDate>\n";
//$contents .= "\t\t\t<author>". tribune_rss_slip($post['login']) ."</author>\n";
  $contents .= "\t\t</item>\n";

  return $contents;
}

function tribune_rss_slip($string) {
  require_once "tribune.sleep.inc";

  $string = tribune_sleep($string, variable_get("tribune_max_message_size", 512));
  $string = preg_replace('#((https?|ftp|gopher|file|mms|rtsp|rtmp)://.*?)((,|\.|\)|\])?(<| | |"|$))#', '<a href="\1">[url]</a>\3', $string);
  $replacements = array(
    '<b>' => '<strong>',
    '</b>' => '</strong>',
    '<i>' => '<em>',
    '</i>' => '</em>',
    '<s>' => '<span style="text-decoration: underline">',
    '</s>' => '</span>',
    '<tt>' => '<code>',
    '</tt>' => '</code>',
  );
  $string = str_replace(array_keys($replacements), array_values($replacements), $string);
  $string = htmlspecialchars($string, ENT_QUOTES, 'UTF-8');

  return $string;
}
